# Simplified version of NLTK book Chapter 6, by Steven Bird, Ewan Klein, and Edward Loper
# Adapted by Amir Zeldes, last edited November 2021

import nltk, random
from nltk.corpus import movie_reviews
from nltk.corpus import stopwords


def document_features(document):
    document_words = set(document)
    features = {}
    for word in top_n:
        features[f'contains({word})'] = (word in document_words)
    return features


eng_stopwords = list(stopwords.words('english'))

lower_words = [word.lower() for word in movie_reviews.words()]
freqs = nltk.FreqDist(lower_words)
top_n = list(freqs)[:2000]
top_n = [word for word in top_n if word not in eng_stopwords]

documents = []
for category in movie_reviews.categories():
    for fileid in movie_reviews.fileids(category):
        words = movie_reviews.words(fileid)
        filtered_words = [word for word in words if word in top_n]
        documents.append((filtered_words,category))
random.shuffle(documents)


feature_sets = []
for doc, category in documents:
    feature_sets.append((document_features(doc), category))

train_set, test_set = feature_sets[100:], feature_sets[:100]
classifier = nltk.NaiveBayesClassifier.train(train_set)

print(nltk.classify.accuracy(classifier, test_set))
classifier.show_most_informative_features(5)
